@@ -157,7 +157,6 @@ class TSFacets(AppObject):
             rql_args,
             selected_facets,
             text_search,
-            quote_to_use_in_sql="''",
         )
 
         with sqlcursor(
@@ -176,12 +175,12 @@ class TSFacets(AppObject):
                     ndoc
                 FROM
                     -- Word-count on all qualified records
-                    ts_stat('
+                    ts_stat($ts_stat$
                         SELECT TSFT.facetvector
                         FROM {self.table_name} as TSFT
                         {sql_restriction_part}
                         {where_sql_part}
-                    ')
+                    $ts_stat$)
                 ORDER BY code, ndoc DESC;
                 """,
                 sql_args,
